@@ -30,7 +30,7 @@ from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import Column
 from sqlalchemy import (
     String, Integer, SmallInteger, Date, Time, Numeric, Boolean)
-from sqlalchemy.orm import relationship
+from sqlalchemy.orm import relationship, object_mapper
 from sqlalchemy.ext.associationproxy import association_proxy
 
 import datetime
@@ -88,7 +88,7 @@ class Customer(Base):
         'Zipcode', String(length=9), nullable=False, default='')
 
     phone_number = Column(
-        'PhoneNumber', String(length=10), nullable=False, default='')
+        'PhoneNumber', String(length=10), nullable=False, default='0000000000')
 
     social_security_number = Column(
         'SSNumber', String(length=9), nullable=False, default='000000000')
@@ -109,7 +109,8 @@ class Customer(Base):
         else:
             self._DateOpened = date.strftime('%m%d%y')
 
-    date_opened = property(_get_date_opened, _set_date_opened)
+    date_opened = property(
+        _get_date_opened, _set_date_opened)
 
     tax_exempt_code = Column(
         'TaxExemptCode', String(length=12), nullable=False, default='000000000000')
@@ -117,12 +118,30 @@ class Customer(Base):
     checking_account_number = Column(
         'CheckingAcctNum', String(length=12), nullable=False, default='000000000000')
 
-    number_visits_to_date = Column(
+    _NumVisitsTD = Column(
         'NumVisitsTD', String(length=3), nullable=False, default='000')
 
-    number_visits_period_to_date = Column(
+    def _get_number_visits_to_date(self):
+        return int(self._NumVisitsTD)
+
+    def _set_number_visits_to_date(self, visits):
+        self._NumVisitsTD = '{0:03d}'.format(int(visits))
+
+    number_visits_to_date = property(
+        _get_number_visits_to_date, _set_number_visits_to_date)
+
+    _NumVisitsPTD = Column(
         'NumVisitsPTD', String(length=3), nullable=False, default='000')
 
+    def _get_number_visits_period_to_date(self):
+        return int(self._NumVisitsPTD)
+
+    def _set_number_visits_period_to_date(self, visits):
+        self._NumVisitsPTD = '{0:03d}'.format(int(visits))
+
+    number_visits_period_to_date = property(
+        _get_number_visits_period_to_date, _set_number_visits_period_to_date)
+
     purchase_amount_to_date = Column(
         'PurchaseAmountTD', String(length=9), nullable=False, default='000000000')
 
@@ -145,7 +164,8 @@ class Customer(Base):
         else:
             self._DOLPurchase = date.strftime('%m%d%y')
 
-    date_of_last_purchase = property(_get_date_of_last_purchase, _set_date_of_last_purchase)
+    date_of_last_purchase = property(
+        _get_date_of_last_purchase, _set_date_of_last_purchase)
 
     comments = Column(
         'Comments', String(length=30), nullable=False, default='')
@@ -156,12 +176,38 @@ class Customer(Base):
     account_status = Column(
         'AccountStatus', String(length=1), nullable=False, default='0')
 
-    frequent_shopper_dollars_to_date = Column(
+    _FSDollarsTD = Column(
         'FSDollarsTD', String(length=9), nullable=False, default='000000000')
 
-    frequent_shopper_dollars_period_to_date = Column(
+    def _get_frequent_shopper_dollars_to_date(self):
+        return Decimal('{0}.{1}'.format(self._FSDollarsTD[:-2], self._FSDollarsTD[-2:]))
+
+    def _set_frequent_shopper_dollars_to_date(self, dollars):
+        if isinstance(dollars, basestring):
+            dollars = int(dollars)
+        else:
+            dollars = int(dollars * 100)
+        self._FSDollarsTD = '{0:09d}'.format(dollars)
+
+    frequent_shopper_dollars_to_date = property(
+        _get_frequent_shopper_dollars_to_date, _set_frequent_shopper_dollars_to_date)
+
+    _FSDollarsPTD = Column(
         'FSDollarsPTD', String(length=9), nullable=False, default='000000000')
 
+    def _get_frequent_shopper_dollars_period_to_date(self):
+        return Decimal('{0}.{1}'.format(self._FSDollarsPTD[:-2], self._FSDollarsPTD[-2:]))
+
+    def _set_frequent_shopper_dollars_period_to_date(self, dollars):
+        if isinstance(dollars, basestring):
+            dollars = int(dollars)
+        else:
+            dollars = int(dollars * 100)
+        self._FSDollarsPTD = '{0:09d}'.format(dollars)
+
+    frequent_shopper_dollars_period_to_date = property(
+        _get_frequent_shopper_dollars_period_to_date, _set_frequent_shopper_dollars_period_to_date)
+
     number_checks_today = Column(
         'NumChecksToday', String(length=1), nullable=False, default='0')
 
@@ -177,9 +223,8 @@ class Customer(Base):
     record_changed = Column(
         'RecordChanged', String(length=1), nullable=False, default='0')
 
-    # TODO: Give this column a default value?  Not sure what its meaning is yet.
     update_flag = Column(
-        'UpdateFlag', String(length=1), nullable=False)
+        'UpdateFlag', String(length=1), nullable=False, default='0')
 
     # TODO: Give this column a default value?  Might need to be business-specific?
     frequent_shopper_level = Column(
@@ -236,6 +281,25 @@ class Customer(Base):
     blanks = Column(
         'Blanks', String(length=12), nullable=True, default='000000000000')
 
+    def __init__(self, **kwargs):
+        """
+        Custom constructor to provide default attribute values.
+
+        This leverages column defaults in order to initially populate the
+        object instance.
+        """
+        for attr in object_mapper(self).column_attrs:
+            if attr.key not in kwargs:
+                column = attr.columns[0]
+                if column.default:
+                    setattr(self, attr.key, column.default.arg)
+        # Kwargs always overrides default values.  This is especially necessary
+        # since some attributes are "raw" columns and others use property
+        # function wrappers.  Therefore the property will be set after the
+        # column has provided the default value.
+        for key, value in kwargs.iteritems():
+            setattr(self, key, value)
+
     def __repr__(self):
         return "Customer(account_number={0})".format(
             repr(self.account_number))
@@ -904,7 +968,8 @@ class ChargeHistory(Base):
         else:
             self._BUSINESSDATE = date.strftime('%y%m%d')
 
-    business_date = property(_get_business_date, _set_business_date)
+    business_date = property(
+        _get_business_date, _set_business_date)
 
     _BUSINESSTIME = Column(
         'BUSINESSTIME', String(length=4), nullable=True)
@@ -920,7 +985,8 @@ class ChargeHistory(Base):
         else:
             self._BUSINESSTIME = time.strftime('%H%M')
 
-    business_time = property(_get_business_time, _set_business_time)
+    business_time = property(
+        _get_business_time, _set_business_time)
 
     @property
     def occurred(self):
@@ -960,7 +1026,8 @@ class ChargeHistory(Base):
         else:
             self._AMOUNT = '{0:08d}'.format(int(amount * 100))
 
-    amount = property(_get_amount, _set_amount)
+    amount = property(
+        _get_amount, _set_amount)
 
     export_flag = Column(
         'EXPORTFLAG', String(length=1), nullable=True)
